@@ -1,7 +1,7 @@
 SETUP_INFO = dict(
     name='getlino',
-    version='21.6.1',
-    install_requires=['click', 'virtualenv', 'jinja2', 'distro', 'rstgen'],
+    version='22.5.0',
+    install_requires=['click', 'virtualenv', 'jinja2', 'distro', 'rstgen', 'GitPython'],
     # tests_require=['docker', 'atelier'],
     # test_suite='tests',
     description="A command-line tool for installing Lino in different environments.",
